.. _spider_puls4.com:

puls4.com
---------
Newest episodes of TV shows from `puls4.com <https://www.puls4.com>`_.

Configuration
~~~~~~~~~~~~~
Add ``puls4.com`` to the list of spiders:

.. code-block:: ini

   # List of spiders to run by default, one per line.
   spiders =
     puls4.com

